==> knative-model-4.4.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/SubscriptionStatusFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.v1.ConditionFluentImpl;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class SubscriptionStatusFluentImpl<A extends SubscriptionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SubscriptionStatusFluent<A>{

    private List<ConditionBuilder> conditions;
    private Long observedGeneration;
    private SubscriptionStatusPhysicalSubscriptionBuilder physicalSubscription;

    public SubscriptionStatusFluentImpl(){
    }
    public SubscriptionStatusFluentImpl(SubscriptionStatus instance){
            this.withConditions(instance.getConditions()); 
            this.withObservedGeneration(instance.getObservedGeneration()); 
            this.withPhysicalSubscription(instance.getPhysicalSubscription()); 
    }

    public A addToConditions(int index,Condition item){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,Condition item){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            ConditionBuilder builder = new ConditionBuilder(item);
            if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(Condition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<Condition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(Condition... items){
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<Condition> items){
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions(){
            return build(conditions);
    }

    public List<Condition> buildConditions(){
            return build(conditions);
    }

    public Condition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public Condition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public Condition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            for (ConditionBuilder item: conditions) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            for (ConditionBuilder item: conditions) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withConditions(List<Condition> conditions){
            if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<ConditionBuilder>(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = new ArrayList<ConditionBuilder>();} return (A) this;
    }

    public A withConditions(Condition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item){
            return new ConditionsNestedImpl(index, item);
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    
/**
 * This method has been deprecated, please use method buildPhysicalSubscription instead.
 * @return The buildable object.
 */
@Deprecated public SubscriptionStatusPhysicalSubscription getPhysicalSubscription(){
            return this.physicalSubscription!=null?this.physicalSubscription.build():null;
    }

    public SubscriptionStatusPhysicalSubscription buildPhysicalSubscription(){
            return this.physicalSubscription!=null?this.physicalSubscription.build():null;
    }

    public A withPhysicalSubscription(SubscriptionStatusPhysicalSubscription physicalSubscription){
            _visitables.get("physicalSubscription").remove(this.physicalSubscription);
            if (physicalSubscription!=null){ this.physicalSubscription= new SubscriptionStatusPhysicalSubscriptionBuilder(physicalSubscription); _visitables.get("physicalSubscription").add(this.physicalSubscription);} return (A) this;
    }

    public Boolean hasPhysicalSubscription(){
            return this.physicalSubscription != null;
    }

    public A withNewPhysicalSubscription(String replyURI,String subscriberURI){
            return (A)withPhysicalSubscription(new SubscriptionStatusPhysicalSubscription(replyURI, subscriberURI));
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscription(){
            return new PhysicalSubscriptionNestedImpl();
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item){
            return new PhysicalSubscriptionNestedImpl(item);
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editPhysicalSubscription(){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription());
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscription(){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription() != null ? getPhysicalSubscription(): new SubscriptionStatusPhysicalSubscriptionBuilder().build());
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription() != null ? getPhysicalSubscription(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SubscriptionStatusFluentImpl that = (SubscriptionStatusFluentImpl) o;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (physicalSubscription != null ? !physicalSubscription.equals(that.physicalSubscription) :that.physicalSubscription != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends ConditionFluentImpl<SubscriptionStatusFluent.ConditionsNested<N>> implements SubscriptionStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,Condition item){
                    this.index = index;
                    this.builder = new ConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new ConditionBuilder(this);
            }
    
    public N and(){
            return (N) SubscriptionStatusFluentImpl.this.setToConditions(index, builder.build());
    }
    public N endCondition(){
            return and();
    }

}
    public class PhysicalSubscriptionNestedImpl<N> extends SubscriptionStatusPhysicalSubscriptionFluentImpl<SubscriptionStatusFluent.PhysicalSubscriptionNested<N>> implements SubscriptionStatusFluent.PhysicalSubscriptionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final SubscriptionStatusPhysicalSubscriptionBuilder builder;
    
            PhysicalSubscriptionNestedImpl(SubscriptionStatusPhysicalSubscription item){
                    this.builder = new SubscriptionStatusPhysicalSubscriptionBuilder(this, item);
            }
            PhysicalSubscriptionNestedImpl(){
                    this.builder = new SubscriptionStatusPhysicalSubscriptionBuilder(this);
            }
    
    public N and(){
            return (N) SubscriptionStatusFluentImpl.this.withPhysicalSubscription(builder.build());
    }
    public N endPhysicalSubscription(){
            return and();
    }

}


}

==> knative-model-4.8.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/SubscriptionStatusFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.v1.ConditionFluentImpl;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class SubscriptionStatusFluentImpl<A extends SubscriptionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SubscriptionStatusFluent<A>{

    private List<ConditionBuilder> conditions;
    private Long observedGeneration;
    private SubscriptionStatusPhysicalSubscriptionBuilder physicalSubscription;

    public SubscriptionStatusFluentImpl(){
    }
    public SubscriptionStatusFluentImpl(SubscriptionStatus instance){
            this.withConditions(instance.getConditions()); 
            this.withObservedGeneration(instance.getObservedGeneration()); 
            this.withPhysicalSubscription(instance.getPhysicalSubscription()); 
    }

    public A addToConditions(int index,Condition item){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,Condition item){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            ConditionBuilder builder = new ConditionBuilder(item);
            if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(Condition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<Condition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(Condition... items){
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<Condition> items){
            for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            if (conditions == null) return (A) this;
            final Iterator<ConditionBuilder> each = conditions.iterator();
            final List visitables = _visitables.get("conditions");
            while (each.hasNext()) {
              ConditionBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions(){
            return build(conditions);
    }

    public List<Condition> buildConditions(){
            return build(conditions);
    }

    public Condition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public Condition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public Condition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            for (ConditionBuilder item: conditions) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            for (ConditionBuilder item: conditions) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withConditions(List<Condition> conditions){
            if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<ConditionBuilder>(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
    }

    public A withConditions(Condition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item){
            return new ConditionsNestedImpl(index, item);
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    
/**
 * This method has been deprecated, please use method buildPhysicalSubscription instead.
 * @return The buildable object.
 */
@Deprecated public SubscriptionStatusPhysicalSubscription getPhysicalSubscription(){
            return this.physicalSubscription!=null?this.physicalSubscription.build():null;
    }

    public SubscriptionStatusPhysicalSubscription buildPhysicalSubscription(){
            return this.physicalSubscription!=null?this.physicalSubscription.build():null;
    }

    public A withPhysicalSubscription(SubscriptionStatusPhysicalSubscription physicalSubscription){
            _visitables.get("physicalSubscription").remove(this.physicalSubscription);
            if (physicalSubscription!=null){ this.physicalSubscription= new SubscriptionStatusPhysicalSubscriptionBuilder(physicalSubscription); _visitables.get("physicalSubscription").add(this.physicalSubscription);} return (A) this;
    }

    public Boolean hasPhysicalSubscription(){
            return this.physicalSubscription != null;
    }

    public A withNewPhysicalSubscription(String replyURI,String subscriberURI){
            return (A)withPhysicalSubscription(new SubscriptionStatusPhysicalSubscription(replyURI, subscriberURI));
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscription(){
            return new PhysicalSubscriptionNestedImpl();
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item){
            return new PhysicalSubscriptionNestedImpl(item);
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editPhysicalSubscription(){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription());
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscription(){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription() != null ? getPhysicalSubscription(): new SubscriptionStatusPhysicalSubscriptionBuilder().build());
    }

    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item){
            return withNewPhysicalSubscriptionLike(getPhysicalSubscription() != null ? getPhysicalSubscription(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            SubscriptionStatusFluentImpl that = (SubscriptionStatusFluentImpl) o;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (physicalSubscription != null ? !physicalSubscription.equals(that.physicalSubscription) :that.physicalSubscription != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends ConditionFluentImpl<SubscriptionStatusFluent.ConditionsNested<N>> implements SubscriptionStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,Condition item){
                    this.index = index;
                    this.builder = new ConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new ConditionBuilder(this);
            }
    
    public N and(){
            return (N) SubscriptionStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition(){
            return and();
    }

}
    public class PhysicalSubscriptionNestedImpl<N> extends SubscriptionStatusPhysicalSubscriptionFluentImpl<SubscriptionStatusFluent.PhysicalSubscriptionNested<N>> implements SubscriptionStatusFluent.PhysicalSubscriptionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final SubscriptionStatusPhysicalSubscriptionBuilder builder;
    
            PhysicalSubscriptionNestedImpl(SubscriptionStatusPhysicalSubscription item){
                    this.builder = new SubscriptionStatusPhysicalSubscriptionBuilder(this, item);
            }
            PhysicalSubscriptionNestedImpl(){
                    this.builder = new SubscriptionStatusPhysicalSubscriptionBuilder(this);
            }
    
    public N and(){
            return (N) SubscriptionStatusFluentImpl.this.withPhysicalSubscription(builder.build());
    }
    public N endPhysicalSubscription(){
            return and();
    }

}


}
